@@ -1,7 +1,5 @@
 import urllib.parse
-
-from sp_api.api.products.models.get_pricing_response import GetPricingResponse
-from sp_api.base import Client, Marketplaces, sp_endpoint
+from sp_api.base import ApiResponse, Client, fill_query_params, sp_endpoint
 
 
 class Products(Client):
@@ -9,12 +7,10 @@ class Products(Client):
     :link: https://github.com/amzn/selling-partner-api-docs/blob/main/references/product-pricing-api/productPricingV0.md
     """
 
-
-
     @sp_endpoint('/products/pricing/v0/price', method='GET')
-    def get_product_pricing_for_skus(self, seller_sku_list: [str], item_condition=None, **kwargs) -> GetPricingResponse:
+    def get_product_pricing_for_skus(self, seller_sku_list: [str], item_condition=None, **kwargs) -> ApiResponse:
         """
-        get_product_pricing_for_skus(self, seller_sku_list: [str], item_condition: str = None, **kwargs) -> GetPricingResponse
+        get_product_pricing_for_skus(self, seller_sku_list: [str], item_condition: str = None, **kwargs) -> ApiResponse
         Returns pricing information for a seller's offer listings based on SKU.
 
         **Usage Plan:**
@@ -32,7 +28,7 @@ class Products(Client):
             **kwargs:
 
         Returns:
-            GetPricingResponse:
+            ApiResponse:
         """
         if item_condition is not None:
             kwargs['ItemCondition'] = item_condition
@@ -40,9 +36,9 @@ class Products(Client):
         return self._create_get_pricing_request(seller_sku_list, 'Sku', **kwargs)
 
     @sp_endpoint('/products/pricing/v0/price', method='GET')
-    def get_product_pricing_for_asins(self, asin_list: [str], item_condition=None, **kwargs) -> GetPricingResponse:
+    def get_product_pricing_for_asins(self, asin_list: [str], item_condition=None, **kwargs) -> ApiResponse:
         """
-        get_product_pricing_for_asins(self, asin_list: [str], item_condition=None, **kwargs) -> GetPricingResponse
+        get_product_pricing_for_asins(self, asin_list: [str], item_condition=None, **kwargs) -> ApiResponse
         Returns pricing information for a seller's offer listings based on ASIN.
 
         **Usage Plan:**
@@ -59,7 +55,7 @@ class Products(Client):
            Filters the offer listings based on item condition. Possible values: New, Used, Collectible, Refurbished, Club.
            Available values : New, Used, Collectible, Refurbished, Club
         :param kwargs:
-        :return:
+        :return: ApiResponse
         """
         if item_condition is not None:
             kwargs['ItemCondition'] = item_condition
@@ -67,9 +63,9 @@ class Products(Client):
         return self._create_get_pricing_request(asin_list, 'Asin', **kwargs)
 
     @sp_endpoint('/products/pricing/v0/competitivePrice', method='GET')
-    def get_competitive_pricing_for_skus(self, seller_sku_list: [str], **kwargs):
+    def get_competitive_pricing_for_skus(self, seller_sku_list: [str], **kwargs) -> ApiResponse:
         """
-        get_competitive_pricing_for_skus(self, seller_sku_list, **kwargs)
+        get_competitive_pricing_for_skus(self, seller_sku_list, **kwargs) -> ApiResponse
         Returns competitive pricing information for a seller's offer listings based on Seller Sku
 
         **Usage Plan:**
@@ -83,14 +79,14 @@ class Products(Client):
 
         :param seller_sku_list: [str]
         :param kwargs:
-        :return:
+        :return: ApiResponse
         """
         return self._create_get_pricing_request(seller_sku_list, 'Sku', **kwargs)
 
     @sp_endpoint('/products/pricing/v0/competitivePrice', method='GET')
-    def get_competitive_pricing_for_asins(self, asin_list: [str], **kwargs) -> GetPricingResponse:
+    def get_competitive_pricing_for_asins(self, asin_list: [str], **kwargs) -> ApiResponse:
         """
-        get_competitive_pricing_for_asins(self, asin_list, **kwargs) -> GetPricingResponse
+        get_competitive_pricing_for_asins(self, asin_list, **kwargs) -> ApiResponse
         Returns competitive pricing information for a seller's offer listings based on ASIN
 
         **Usage Plan:**
@@ -109,27 +105,36 @@ class Products(Client):
         """
         return self._create_get_pricing_request(asin_list, 'Asin', **kwargs)
 
-    def _create_get_pricing_request(self, item_list, item_type, **kwargs):
+    @sp_endpoint('/products/pricing/v0/listings/{}/offers', method='GET')
+    def get_listings_offer(self, seller_sku: str, **kwargs) -> ApiResponse:
         """
-        Returns pricing information for a seller's offer listings based on seller SKU or ASIN.
+        get_listings_offer(self, seller_sku: str, **kwargs) -> ApiResponse
+        Returns the lowest priced offers for a single SKU listing
 
         **Usage Plan:**
 
-        | Rate (requests per second) | Burst |
-        | ---- | ---- |
-        | 1 | 1 |
+        ======================================  ==============
+        Rate (requests per second)               Burst
+        ======================================  ==============
+        1                                       1
+        ======================================  ==============
 
-        For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
+        Args:
+            :param seller_sku: str
+            key ItemCondition: str | Possible values: New, Used, Collectible, Refurbished, Club.
+            key MarketplaceId: str
+
+        Returns:
+            GetOffersResponse:
 
-        :param item_list:
-        :param item_type:
-        :param kwargs:
-        :return:
         """
-        return GetPricingResponse(
-            **self._request(kwargs.pop('path'),
-                            params={**{f"{item_type}s": ','.join(
-                                [urllib.parse.quote_plus(s) for s in item_list])},
-                                    'ItemType': item_type,
-                                    **({'ItemCondition': kwargs.pop('ItemCondition')} if 'ItemCondition' in kwargs else {}),
-                                    'MarketplaceId': kwargs.get('MarketplaceId', self.marketplace_id)}).json())
+        return self._request(fill_query_params(kwargs.pop('path'), seller_sku), params={**kwargs})       
+
+    def _create_get_pricing_request(self, item_list, item_type, **kwargs):
+        return self._request(kwargs.pop('path'),
+                             params={**{f"{item_type}s": ','.join(
+                                 [urllib.parse.quote_plus(s) for s in item_list])},
+                                     'ItemType': item_type,
+                                     **({'ItemCondition': kwargs.pop(
+                                         'ItemCondition')} if 'ItemCondition' in kwargs else {}),
+                                     'MarketplaceId': kwargs.get('MarketplaceId', self.marketplace_id)})
